% Numerical calcualtion of tilt-angel alpha

clc 
clear all
format long

%---------------------------------------------------
%Variabels

L = 50;          %Diameter of floating collar [m]
d = 5;           %Diameter of air-dome [m]
a = 23;          %Mooring line length (between flaoting collar and air-dome [m]
B = 20000;       % Vertical force (buoyancy) [N]
F = 19000;       % Horizontal force (drag) [N]
my = acos((L-d)/(2*a)); %Angel of mooring lines, between the floating collar
                        %and air-dome at F=0 [rad]
                        
%-----------------------------------------------------
%Establishing dimensionless variabel of L, d og a

lambda = L/L;
delta = d/L;
alfa = a/L;

%-------------------------------------------------------
%x1 = sin(beta1); at F=0 is x1=sin(my)
x1 = 0.000:0.005:0.4;
%y  = sin(alpha); at F=0 is y=0
y  = 0.000:0.005:0.4;

%--------------------------------------------------------
%Making 2D grid-coordinates
[x1, y] = meshgrid(x1,y);

%--------------------------------------------------------
%from (4) in the report x2 can be written as:
x2 = x1 + delta.*y/alfa;

%from (2) og (1) S1 and S2 are expressed in the following way:
S1teller = B.*sqrt(1-x2.^2) + F.*x2;
S2teller = B.*sqrt(1-x1.^2) - F.*x1;
Snevner = x2.*sqrt(1-x1.^2)+x1.*sqrt(1-x2.^2);
S1 = S1teller./Snevner;
S2 = S2teller./Snevner;

%--------------------------------------------------------------------
%Making dimensionless variabels for the forces acting on the air-dome
%Trying to scale the forces som that f3 og f5 varies approximately the
%same.

scale = 0.02;
phi = (F/B)*scale;
sigma1 = (S1/B)*scale;
sigma2 = (S2/B)*scale;

%----------------------------------------------------------------------
%Establishing f3 and f5, the left side of (3a) and (5a) from the report
f3 = lambda - delta.*sqrt(1-y.^2) - alfa.*(sqrt(1-x1.^2)+sqrt(1-x2.^2));
f5 = sigma2.*(y.*sqrt(1-x2.^2)+x2.*sqrt(1-y.^2))-sigma1.*(x1.*sqrt(1-y.^2)-y.*sqrt(1-x1.^2));

%----------------------------------------------------------------------
%Making a matrix with zeros to mark the (x1,y)-plane in the figure
x1yplane = 0.0.*x1.*y;

%----------------------------------------------------------------------
%Plot
%Plotting f3, f5 and (x1,y)-plane in the same figure


figure(1)
h1=surf(x1,y,f3,'FaceColor','r');
hold on
h2=surf(x1,y,f5,'FaceColor','y');
h3=surf(x1,y,x1yplane,'FaceColor','g');
legend([h1,h2,h3],{'Geometry constraints','Static equilibrium','xy-plane'})
zlabel('f3 og f5')
xlabel({'$\sin\beta_1$'},'Interpreter','latex')
ylabel({'$\sin\alpha$'},'Interpreter','latex')
view(2)

%Initially the z-intervall are set manualy to get a good figure
zlim([-0.015 0.015])



